/****************************************************************************
** Meta object code from reading C++ file 'kcmaccessibilityactivationgestures.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../kcmaccessibilityactivationgestures.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmaccessibilityactivationgestures.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26ActivationGesturesSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto ActivationGesturesSettings::qt_create_metaobjectdata<qt_meta_tag_ZN26ActivationGesturesSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ActivationGesturesSettings",
        "GesturesChanged",
        "",
        "GestureConfirmationChanged",
        "KeyboardNotifyAccessChanged",
        "AccessXTimeoutChanged",
        "AccessXTimeoutDelayChanged",
        "AccessXBeepChanged",
        "gestures",
        "isGesturesImmutable",
        "defaultGesturesValue",
        "gestureConfirmation",
        "isGestureConfirmationImmutable",
        "defaultGestureConfirmationValue",
        "keyboardNotifyAccess",
        "isKeyboardNotifyAccessImmutable",
        "defaultKeyboardNotifyAccessValue",
        "accessXTimeout",
        "isAccessXTimeoutImmutable",
        "defaultAccessXTimeoutValue",
        "accessXTimeoutDelay",
        "isAccessXTimeoutDelayImmutable",
        "defaultAccessXTimeoutDelayValue",
        "accessXBeep",
        "isAccessXBeepImmutable",
        "defaultAccessXBeepValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'GesturesChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GestureConfirmationChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'KeyboardNotifyAccessChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AccessXTimeoutChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AccessXTimeoutDelayChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AccessXBeepChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'gestures'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isGesturesImmutable'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGesturesValue'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gestureConfirmation'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isGestureConfirmationImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGestureConfirmationValue'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'keyboardNotifyAccess'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isKeyboardNotifyAccessImmutable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultKeyboardNotifyAccessValue'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'accessXTimeout'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isAccessXTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAccessXTimeoutValue'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'accessXTimeoutDelay'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isAccessXTimeoutDelayImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAccessXTimeoutDelayValue'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'accessXBeep'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isAccessXBeepImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAccessXBeepValue'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ActivationGesturesSettings, qt_meta_tag_ZN26ActivationGesturesSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ActivationGesturesSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26ActivationGesturesSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26ActivationGesturesSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26ActivationGesturesSettingsE_t>.metaTypes,
    nullptr
} };

void ActivationGesturesSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActivationGesturesSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->GesturesChanged(); break;
        case 1: _t->GestureConfirmationChanged(); break;
        case 2: _t->KeyboardNotifyAccessChanged(); break;
        case 3: _t->AccessXTimeoutChanged(); break;
        case 4: _t->AccessXTimeoutDelayChanged(); break;
        case 5: _t->AccessXBeepChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ActivationGesturesSettings::*)()>(_a, &ActivationGesturesSettings::GesturesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivationGesturesSettings::*)()>(_a, &ActivationGesturesSettings::GestureConfirmationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivationGesturesSettings::*)()>(_a, &ActivationGesturesSettings::KeyboardNotifyAccessChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivationGesturesSettings::*)()>(_a, &ActivationGesturesSettings::AccessXTimeoutChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivationGesturesSettings::*)()>(_a, &ActivationGesturesSettings::AccessXTimeoutDelayChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivationGesturesSettings::*)()>(_a, &ActivationGesturesSettings::AccessXBeepChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->gestures(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isGesturesImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultGesturesValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->gestureConfirmation(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isGestureConfirmationImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultGestureConfirmationValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->keyboardNotifyAccess(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isKeyboardNotifyAccessImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultKeyboardNotifyAccessValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->accessXTimeout(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isAccessXTimeoutImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultAccessXTimeoutValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->accessXTimeoutDelay(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isAccessXTimeoutDelayImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultAccessXTimeoutDelayValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->accessXBeep(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isAccessXBeepImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultAccessXBeepValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setGestures(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setGestureConfirmation(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setKeyboardNotifyAccess(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setAccessXTimeout(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setAccessXTimeoutDelay(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setAccessXBeep(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ActivationGesturesSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ActivationGesturesSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26ActivationGesturesSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int ActivationGesturesSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void ActivationGesturesSettings::GesturesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ActivationGesturesSettings::GestureConfirmationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ActivationGesturesSettings::KeyboardNotifyAccessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ActivationGesturesSettings::AccessXTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ActivationGesturesSettings::AccessXTimeoutDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ActivationGesturesSettings::AccessXBeepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
